favorites=mousepad.desktop,xfce4-terminal-emulator.desktop,xfce4-taskmanager.desktop,xfce4-screenshooter.desktop,xfce-settings-manager.desktop,xfce-ui-settings.desktop,xfce-display-settings.desktop,xfhelp4.desktop,xfce4-about.desktop
recent=
button-icon=xubuntu-logo-menu
button-single-row=false
show-button-title=false
show-button-icon=true
launcher-show-name=true
launcher-show-description=false
launcher-show-tooltip=true
item-icon-size=2
hover-switch-category=true
category-show-name=true
category-icon-size=1
load-hierarchy=true
view-as-icons=false
default-category=0
recent-items-max=10
favorites-in-recent=true
position-search-alternate=true
position-commands-alternate=true
position-categories-alternate=false
stay-on-focus-out=false
confirm-session-command=true
menu-width=385
menu-height=463
menu-opacity=100
command-settings=xfce4-settings-manager
show-command-settings=false
command-lockscreen=xflock4
show-command-lockscreen=true
command-switchuser=dm-tool switch-to-greeter
show-command-switchuser=false
command-logoutuser=xfce4-session-logout --logout --fast
show-command-logoutuser=false
command-restart=xfce4-session-logout --reboot --fast
show-command-restart=false
command-shutdown=xfce4-session-logout --halt --fast
show-command-shutdown=true
command-suspend=xfce4-session-logout --suspend
show-command-suspend=true
command-hibernate=xfce4-session-logout --hibernate
show-command-hibernate=false
command-logout=xfce4-session-logout
show-command-logout=true
command-menueditor=menulibre
show-command-menueditor=true
command-profile=mugshot
show-command-profile=true
search-actions=5

[action0]
name=Man Pages
pattern=#
command=exo-open --launch TerminalEmulator man %s
regex=false

[action1]
name=Wikipedia
pattern=!w
command=exo-open --launch WebBrowser https://en.wikipedia.org/wiki/%u
regex=false

[action2]
name=Run in Terminal
pattern=!
command=exo-open --launch TerminalEmulator %s
regex=false

[action3]
name=Open URI
pattern=^(file|http|https):\\/\\/(.*)$
command=exo-open \\0
regex=true

[action4]
name=Search for files
pattern=-
command=catfish --path=~ --start %s
regex=false

